==> LbExec-0.5.1-py3-none-any.whl: LbExec/__init__.py <==
###############################################################################
# (c) Copyright 2022-2023 CERN for the benefit of the LHCb Collaboration      #
#                                                                             #
# This software is distributed under the terms of the GNU General Public      #
# Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
#                                                                             #
# In applying this licence, CERN does not waive the privileges and immunities #
# granted to it by virtue of its status as an Intergovernmental Organization  #
# or submit itself to any jurisdiction.                                       #
###############################################################################
__all__ = ("Options", "main", "skim_and_merge")

import sys

from .options import Options
from .workflows import skim_and_merge


def main(function, options, extra_args):
    """Run a job with lbexec.

    Args:
        function (callable): A callable that will return the Gaudi configuration
        options (Options): An initialised APP.Options object
        extra_args (list of str): list of strings to add the the call to ``function``

    Returns:
        return_code (int): The Gaudi process's return code
    """
    _ = function(options, *extra_args)

    # Ensure that any printout that has been made by the user provided function
    # has been flushed. Without this, non-interactive jobs such as tests end up
    # showing the print out in the middle of the Gaudi application log
    sys.stdout.flush()
    sys.stderr.flush()

    return 0

==> LbExec-0.7.0-py3-none-any.whl: LbExec/__init__.py <==
###############################################################################
# (c) Copyright 2022-2023 CERN for the benefit of the LHCb Collaboration      #
#                                                                             #
# This software is distributed under the terms of the GNU General Public      #
# Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
#                                                                             #
# In applying this licence, CERN does not waive the privileges and immunities #
# granted to it by virtue of its status as an Intergovernmental Organization  #
# or submit itself to any jurisdiction.                                       #
###############################################################################
__all__ = ("Options", "main", "skim_and_merge", "process_trees")

import sys

from .options import Options
from .workflows import process_trees, skim_and_merge


def main(function, options, extra_args):
    """Run a job with lbexec.

    Args:
        function (callable): A callable that will return the Gaudi configuration
        options (Options): An initialised APP.Options object
        extra_args (list of str): list of strings to add the the call to ``function``

    Returns:
        return_code (int): The Gaudi process's return code
    """
    _ = function(options, *extra_args)

    # Ensure that any printout that has been made by the user provided function
    # has been flushed. Without this, non-interactive jobs such as tests end up
    # showing the print out in the middle of the Gaudi application log
    sys.stdout.flush()
    sys.stderr.flush()

    return 0
